@@ -16,7 +16,7 @@ URL_FINISH = "/api/client/run/finish"
 
 
 jwt_key: str = None
-
+use_http: bool =False
 def set_jwt_key(jwt_key_: str) -> None:
     global jwt_key
     jwt_key = jwt_key_
@@ -25,13 +25,21 @@ def get_jwt_key() -> str:
     global jwt_key
     return jwt_key
 
+def set_use_https(use_https_: bool) -> None:
+    global use_http
+    use_http = use_https_
+
+def get_use_https() -> bool:
+    global use_http
+    return use_http
 # 서버의 login api 를 호출하여 API key 값을 서버로 전송하고 결과로서 jwt key 를 받는다.
 # 받은 jwt key 는 메모리에 저장해 두어서 추후 서버와 통신시 헤더에 실어서 보낼 수 있도록 한다.
 def login(http_host: str , api_key: str) -> Dict:
     data = {
         "key": api_key
     }
-    url = ParseResult(scheme="http",netloc=http_host, path=URL_LOGIN, params='', query='', fragment='').geturl()
+
+    url = parse_result_wraaper(http_host,URL_LOGIN)
     rsp = post(url, data)
     logger.debug("login() " + rsp["message"])
     if rsp["result"] == "success":
@@ -62,7 +70,8 @@ def init(http_host: str ,exp_name: str="", team_name: str="", run_name: str="",
         "sysInfo": sys_info,
         "createRun": "Y",
     }
-    url = ParseResult(scheme="http",netloc=http_host, path=URL_CREATE, params='', query='', fragment='').geturl()
+
+    url = parse_result_wraaper(http_host,URL_CREATE)
     rsp = post(url, data)
     logger.debug("init() response : " + rsp["message"])
     return rsp
@@ -82,7 +91,7 @@ def create_hpo(http_host:str, exp_name: str="", team_name: str="", hpo_config: D
             "hostname": util.get_hostname(),
         },
     }
-    url = ParseResult(scheme="http", netloc=http_host, path=URL_CREATE_HPO, params='', query='', fragment='').geturl()
+    url = parse_result_wraaper(http_host,URL_CREATE_HPO)
     rsp = post(url, data)
     logger.debug("create_hpo() response : " + rsp["message"])
     return rsp
@@ -93,14 +102,14 @@ def get_hpo(http_host:str, exp_name: str="", team_name: str="") -> Dict:
         "teamName": team_name,
         "expName": exp_name,
     }
-    url = ParseResult(scheme="http", netloc=http_host, path=URL_GET_HPO, params='', query='', fragment='').geturl()
+    url = parse_result_wraaper(http_host,URL_GET_HPO)
     rsp = post(url, data)
     logger.debug("get_hpo() response : " + rsp["message"])
     return rsp
 
 
 def finish(http_host: str ,data: Dict) -> Dict:
-    url = ParseResult(scheme="http",netloc=http_host, path=URL_FINISH, params='', query='', fragment='').geturl()
+    url = parse_result_wraaper(http_host,URL_FINISH)
     rsp = post(url, data)
     logger.debug("finish() " + rsp["message"])
     return rsp
@@ -126,6 +135,12 @@ def post(url: str, data: Dict) -> Dict:
                 raise Exception(f"request.post() failed({rsp.text if rsp.text else rsp.status_code})", rsp)
     return dict(json.loads(rsp.text))
 
+def parse_result_wraaper(http_host, path):
+    if get_use_https():
+        scheme = "https"
+    else:
+        scheme = "http"
+    return ParseResult(scheme=scheme, netloc=http_host, path=path, params='', query='', fragment='').geturl()
 def get_headers():
     jwt_key = get_jwt_key()
     headers = {
