@@ -31,7 +31,7 @@ def get_stub() -> ResourceStub:
 
 grpc_host : str = "127.0.0.1:19051"
 use_grpc_tls : bool = False # GPRC의 tls(ssl) 사용여부
-
+use_https : bool = False
 def set_grpc_host(grpc_host_: str, use_grpc_tls_=False) -> None:
     global grpc_host
     global use_grpc_tls
@@ -46,14 +46,22 @@ def get_use_grpc_tls() -> bool:
     global use_grpc_tls
     return use_grpc_tls
 
+
+def get_use_https() -> bool:
+    global use_https
+    return use_https
+
 http_host = "127.0.0.1:9011"
 
-def set_http_host(http_host_: str) -> None:
+def set_http_host(http_host_: str, use_https_ = False) -> None:
     global http_host
+    global use_https
     if http_host_.upper().startswith("HTTP"):
         http_host  = urlparse(http_host_).netloc
     else:
         http_host = http_host_
+    use_https =use_https_
+    http_interface.set_use_https(use_https)
 
 
 def get_http_host() -> str:
@@ -336,7 +344,7 @@ def download_artifact():
 
 
 def login(key: str) -> (bool, str):
-    rsp = http_interface.login(get_http_host(), key)
+    rsp = http_interface.login(get_http_host(), key, get_use_https())
     if rsp["result"] == "success":
 
         grpc_url = get_grpc_host()
